@@ -31,13 +31,12 @@ void show_about_dialog(GtkApplication *app)
   GList * windows = gtk_application_get_windows (app);
   
   gtk_show_about_dialog( g_list_nth_data (windows, 0),
-  "program-name", _("Notes"),
+  "program-name", _("Bijiben"),
   "comments", _("Simple notebook for GNOME"),
   "license", "GPLv3",
   "version", VERSION,
-  "copyright", "Pierre-Yves Luyten 2013",
+  "copyright", "Pierre-Yves Luyten 2012",
   "translator-credits", _("translator-credits"),
-  "website", "https://wiki.gnome.org/Bijiben",
   NULL,NULL,NULL);
 
 }
@@ -47,7 +46,16 @@ new_activated (GSimpleAction *action,
                GVariant      *parameter,
                gpointer       user_data)
 {
-  bjb_window_base_new();
+  BjbWindowBase *win;
+  BjbController *control;
+
+  win = BJB_WINDOW_BASE (bjb_window_base_new());
+
+  /* Tell the controller to display all notes, */
+  control = bjb_window_base_get_controller (win);
+  bjb_controller_set_needle (control, "");
+
+  bjb_window_base_switch_to (win, BJB_WINDOW_BASE_MAIN_VIEW);
 }
 
 /* Import external data - TODO : BJB_TYPE_IMPORT_DIALOG.c */
@@ -151,7 +159,7 @@ external_activated (GSimpleAction *action,
 
   windows = gtk_application_get_windows (GTK_APPLICATION(user_data));
 
-  dialog = gtk_dialog_new_with_buttons (_("External Notes"),
+  dialog = gtk_dialog_new_with_buttons (_("Import Notes"),
                                         g_list_nth_data (windows, 0),
                                         GTK_DIALOG_MODAL| 
                                         GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -166,7 +174,7 @@ external_activated (GSimpleAction *action,
   gtk_widget_set_hexpand (area, TRUE);
   gtk_widget_set_vexpand (area, TRUE);
 
-  label = gtk_label_new (_("Click on the external notes to import"));
+  label = gtk_label_new (_("Import notes from:"));
   gtk_box_pack_start (GTK_BOX (area), label, TRUE, FALSE, 2);
 
   store = gtk_list_store_new (IMPORT_DIALOG_N_COLUMNS,
