@@ -51,19 +51,15 @@ bijiben_new_window_internal (GApplication *app,
 
   if (file != NULL)
     note = biji_note_get_new_from_file (g_file_get_path(file));
+
   else if (note_obj != NULL)
     note = note_obj;
 
   if (note != NULL)
-    {
       bjb_window_base_switch_to_note (BJB_WINDOW_BASE (win), note);
-    }
 
   else
-  {
-    bjb_window_base_switch_to (BJB_WINDOW_BASE (win), BJB_MAIN_VIEW);
-    gtk_widget_show_all (GTK_WIDGET (win)); // FIXME not here
-  }
+    bjb_window_base_switch_to (BJB_WINDOW_BASE (win), BJB_WINDOW_BASE_MAIN_VIEW);
 }
 
 void
@@ -183,10 +179,10 @@ go_through_notes_cb (GFileEnumerator *enumerator, GAsyncResult *res, Bijiben *se
   for (l = notes_proposal; l != NULL; l = l->next)
   {
     BijiNoteObj *note = l->data;
-    gchar *path = biji_note_obj_get_path (note);
+    gchar *path = biji_item_get_uuid (BIJI_ITEM (note));
 
     /* Don't add an already imported note */
-    if (note_book_get_note_at_path (self->priv->book, path))
+    if (biji_note_book_get_item_at_path (self->priv->book, path))
     {
       abort_note (note);
     }
@@ -196,7 +192,7 @@ go_through_notes_cb (GFileEnumerator *enumerator, GAsyncResult *res, Bijiben *se
     {
       /* Title */
       unique_title = biji_note_book_get_unique_title (self->priv->book,
-                                                      biji_note_obj_get_title (note));
+                                                      biji_item_get_title (BIJI_ITEM (note)));
       biji_note_obj_set_title (note, unique_title);
       g_free (unique_title);
 
