@@ -46,6 +46,13 @@ enum
 
 static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 
+enum {
+  VIEW_SELECTION_CHANGED,
+  BJB_MAIN_VIEW_SIGNALS
+};
+
+static guint bjb_main_view_signals [BJB_MAIN_VIEW_SIGNALS] = { 0 };
+
 /************************** Gobject ***************************/
 
 struct _BjbMainViewPriv {  
@@ -67,9 +74,9 @@ struct _BjbMainViewPriv {
 
   /* Signals */
   gulong key;
-  gulong button;
   gulong activated;
   gulong data;
+  gulong view_selection_changed;
 };
 
 G_DEFINE_TYPE (BjbMainView, bjb_main_view, GTK_TYPE_BOX);
@@ -79,6 +86,11 @@ bjb_main_view_init (BjbMainView *object)
 {
   object->priv = 
   G_TYPE_INSTANCE_GET_PRIVATE(object,BJB_TYPE_MAIN_VIEW,BjbMainViewPriv);
+
+  object->priv->key = 0;
+  object->priv->activated = 0;
+  object->priv->data = 0;
+  object->priv->view_selection_changed =0;
 }
 
 static void
@@ -93,9 +105,14 @@ bjb_main_view_disconnect_handlers (BjbMainView *self)
   BjbMainViewPriv *priv = self->priv;
 
   g_signal_handler_disconnect (priv->window, priv->key);
-  g_signal_handler_disconnect (priv->view, priv->button);
   g_signal_handler_disconnect (priv->view, priv->activated);
   g_signal_handler_disconnect (priv->view, priv->data);
+  g_signal_handler_disconnect (priv->view, priv->view_selection_changed);
+
+  priv->key = 0;
+  priv->activated = 0;
+  priv->data = 0;
+  priv->view_selection_changed =0;
 }
 
 static void
@@ -184,20 +201,31 @@ show_window_if_note (gpointer data, gpointer user_data)
 }
 
 static void
-switch_to_note (BjbMainView *view, BijiNoteObj *to_open)
+switch_to_note (BjbMainView *view, BijiItem *to_open)
 {
-  /* If the note is already opened in another window, just show it. */
-  if (biji_note_obj_is_opened (to_open))
+  if (BIJI_IS_NOTE_OBJ (to_open))
   {
-    GList *notes ;
+    /* If the note is already opened in another window, just show it. */
+    if (biji_note_obj_is_opened (BIJI_NOTE_OBJ (to_open)))
+    {
+      GList *notes ;
 
-    notes = gtk_application_get_windows(GTK_APPLICATION(g_application_get_default()));
-    g_list_foreach (notes, show_window_if_note, to_open);
-    return ;
+      notes = gtk_application_get_windows(GTK_APPLICATION(g_application_get_default()));
+      g_list_foreach (notes, show_window_if_note, to_open);
+      return ;
+    }
+
+    /* Otherwise, leave main view */
+    switch_to_note_view (view, BIJI_NOTE_OBJ (to_open));
   }
 
-  /* Otherwise, leave main view */
-  switch_to_note_view(view,to_open);
+  /* Collection
+   * TODO : check if already opened (same as above) */
+  else
+  {
+    bjb_controller_set_collection (view->priv->controller,
+                                   biji_item_get_title (to_open));
+  }
 }
 
 static GList *
@@ -221,7 +249,7 @@ get_note_url_from_tree_path(GtkTreePath *path, BjbMainView *self)
 }
 
 void
-action_tag_selected_notes (GtkWidget *w, BjbMainView *view)
+action_tag_selected_items (GtkWidget *w, BjbMainView *view)
 {
   GList *notes = NULL;
   GList *paths, *l;
@@ -232,7 +260,7 @@ action_tag_selected_notes (GtkWidget *w, BjbMainView *view)
   for (l=paths ; l != NULL ; l=l->next)
   {
     gchar *url = get_note_url_from_tree_path (l->data, view) ;
-    notes = g_list_prepend (notes, note_book_get_note_at_path
+    notes = g_list_prepend (notes, biji_note_book_get_item_at_path
                                  (bjb_window_base_get_book(view->priv->window),url));
     g_free (url);
   }
@@ -243,26 +271,29 @@ action_tag_selected_notes (GtkWidget *w, BjbMainView *view)
 }
 
 gboolean
-bjb_main_view_get_selected_notes_color (BjbMainView *view, GdkRGBA *color)
+bjb_main_view_get_selected_items_color (BjbMainView *view, GdkRGBA *color)
 {
   GList *paths;
   gchar *url;
-  BijiNoteObj *note;
+  BijiItem *item;
 
   /*  GtkTreePath */
   paths = get_selected_paths(view);
   url = get_note_url_from_tree_path (paths->data, view) ;
-  note = note_book_get_note_at_path (bjb_window_base_get_book(view->priv->window), url);
+  item = biji_note_book_get_item_at_path (bjb_window_base_get_book(view->priv->window), url);
   g_free (url);
   g_list_free_full (paths, (GDestroyNotify) gtk_tree_path_free);
 
-  return biji_note_obj_get_rgba (note, color);
+  if (BIJI_IS_NOTE_OBJ (item))
+    return biji_note_obj_get_rgba (BIJI_NOTE_OBJ (item), color);
+
+  return FALSE;
 }
 
 void
-action_color_selected_notes (GtkWidget *w, BjbMainView *view)
+action_color_selected_items (GtkWidget *w, BjbMainView *view)
 {
-  GList *notes = NULL ;
+  GList *items = NULL ;
   GList *paths, *l;
 
   GdkRGBA color;
@@ -274,25 +305,26 @@ action_color_selected_notes (GtkWidget *w, BjbMainView *view)
   for (l=paths ; l != NULL ; l=l->next)
   {
     gchar *url = get_note_url_from_tree_path (l->data, view) ;
-    notes = g_list_prepend (notes, note_book_get_note_at_path
+    items = g_list_prepend (items, biji_note_book_get_item_at_path
                                    (bjb_window_base_get_book(view->priv->window),url));
     g_free (url);
   }
 
   g_list_free_full (paths, (GDestroyNotify) gtk_tree_path_free);
 
-  for (l=notes ; l != NULL ; l=l->next)
+  for (l=items ; l != NULL ; l=l->next)
   {
-    biji_note_obj_set_rgba (BIJI_NOTE_OBJ (l->data), &color);
+    if (BIJI_IS_NOTE_OBJ (l->data))
+      biji_note_obj_set_rgba (BIJI_NOTE_OBJ (l->data), &color);
   }
 
-  g_list_free (notes);
+  g_list_free (items);
 }
 
 void
-action_delete_selected_notes(GtkWidget *w,BjbMainView *view)
+action_delete_selected_items (GtkWidget *w, BjbMainView *view)
 {
-  GList *notes = NULL;
+  GList *items = NULL;
   GList *paths, *l;
 
   /*  GtkTreePath */
@@ -301,20 +333,39 @@ action_delete_selected_notes(GtkWidget *w,BjbMainView *view)
   for (l=paths ; l != NULL ; l=l->next)
   {
     gchar *url = get_note_url_from_tree_path (l->data, view) ;
-    notes = g_list_prepend (notes, note_book_get_note_at_path
+    items = g_list_prepend (items, biji_note_book_get_item_at_path
                                (bjb_window_base_get_book(view->priv->window),url));
     g_free (url);
   }
 
   g_list_free_full (paths, (GDestroyNotify) gtk_tree_path_free);
 
-  for (l=notes ; l != NULL ; l=l->next)
+  for (l=items ; l != NULL ; l=l->next)
   {
-    biji_note_book_remove_note (bjb_window_base_get_book (view->priv->window),
-                                BIJI_NOTE_OBJ (l->data));
+    biji_note_book_remove_item (bjb_window_base_get_book (view->priv->window),
+                                BIJI_ITEM (l->data));
   }
 
-  g_list_free (notes);
+  g_list_free (items);
+}
+
+static void
+on_selection_mode_changed_cb (BjbMainView *self)
+{
+  GList *select;
+
+  /* Workaround if items are selected
+   * but selection mode not really active (?) */
+  select = gd_main_view_get_selection (self->priv->view);
+  if (select)
+  {
+    g_list_free (select);
+    gd_main_view_set_selection_mode (self->priv->view, TRUE);
+  }
+
+  /* Any case, tell */
+  g_signal_emit (G_OBJECT (self),
+                 bjb_main_view_signals[VIEW_SELECTION_CHANGED],0);
 }
 
 /* Select all, escape */
@@ -341,7 +392,6 @@ on_key_press_event_cb (GtkWidget *widget,
       if (gd_main_view_get_selection_mode (priv->view))
       {
         gd_main_view_set_selection_mode (priv->view, FALSE);
-        on_selection_mode_changed (priv->main_toolbar);
         return TRUE;
       }
 
@@ -352,40 +402,14 @@ on_key_press_event_cb (GtkWidget *widget,
   return FALSE;
 }
 
-/* Go to selection mode with right-click */
 static gboolean
-on_button_press_event_cb (GtkWidget *widget,
-                          GdkEvent  *event,
-                          gpointer   user_data)
-{
-  BjbMainView *self = BJB_MAIN_VIEW (user_data);
-  BjbMainViewPriv *priv = self->priv;
-
-  switch (event->button.button)
-  {
-    /* Right click */
-    case 3:
-      if (!gd_main_view_get_selection_mode (priv->view))
-      {
-        gd_main_view_set_selection_mode (priv->view, TRUE);
-        on_selection_mode_changed (priv->main_toolbar);
-      }
-
-      return TRUE;
-
-    default:
-      return FALSE;
-  }
-}
-
-static gboolean
-on_item_activated(GdMainView        * gd, 
-                  const gchar       * id,
-                  const GtkTreePath * path,
-                  BjbMainView       * view)
+on_item_activated (GdMainView        * gd,
+                   const gchar       * id,
+                   const GtkTreePath * path,
+                   BjbMainView       * view)
 {
   BijiNoteBook * book ;
-  BijiNoteObj  * to_open ;
+  BijiItem     * to_open ;
   GtkTreeIter    iter ;
   gchar        * note_path ;
   GtkTreeModel * model ;
@@ -397,7 +421,7 @@ on_item_activated(GdMainView        * gd,
 
   /* Switch to that note */
   book = bjb_window_base_get_book (view->priv->window); 
-  to_open = note_book_get_note_at_path (book, note_path);
+  to_open = biji_note_book_get_item_at_path (book, note_path);
   g_free (note_path);
   switch_to_note (view, to_open); 
 
@@ -452,13 +476,23 @@ bjb_main_view_connect_signals (BjbMainView *self)
   bjb_controller_connect (priv->controller);
   bjb_search_toolbar_connect (priv->search_bar);
 
-  priv->key = g_signal_connect (priv->window, "key-press-event",
+  if (priv->view_selection_changed == 0)
+    priv->view_selection_changed = g_signal_connect_swapped
+                                  (priv->view,
+                                   "view-selection-changed",
+                                   G_CALLBACK (on_selection_mode_changed_cb),
+                                   self);
+
+  if (priv->key == 0)
+    priv->key = g_signal_connect (priv->window, "key-press-event",
                               G_CALLBACK (on_key_press_event_cb), self);
-  priv->button = g_signal_connect (priv->view, "button-press-event",
-                           G_CALLBACK (on_button_press_event_cb), self);
-  priv->activated = g_signal_connect(priv->view,"item-activated",
+
+  if (priv->activated == 0)
+    priv->activated = g_signal_connect(priv->view,"item-activated",
                                     G_CALLBACK(on_item_activated),self);
-  priv->data = g_signal_connect (priv->view, "drag-data-received",
+
+  if (priv->data == 0)
+    priv->data = g_signal_connect (priv->view, "drag-data-received",
                               G_CALLBACK (on_drag_data_received), self);
 }
 
@@ -482,11 +516,6 @@ bjb_main_view_constructed(GObject *o)
   gtk_orientable_set_orientation (GTK_ORIENTABLE (self), GTK_ORIENTATION_VERTICAL);
 
   priv->view = gd_main_view_new (DEFAULT_VIEW);
-  bjb_controller_set_main_view (priv->controller, priv->view);
-
-  /* main Toolbar */
-  priv->main_toolbar = bjb_main_toolbar_new (priv->view, self, priv->controller);
-  gtk_box_pack_start (vbox, GTK_WIDGET (priv->main_toolbar), FALSE, FALSE, 0);
 
   /* Search entry toolbar */
   priv->search_bar = bjb_search_toolbar_new (priv->window, priv->controller);
@@ -544,6 +573,17 @@ bjb_main_view_class_init (BjbMainViewClass *klass)
                                                          G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, NUM_PROPERTIES, properties);
+
+  bjb_main_view_signals[VIEW_SELECTION_CHANGED] = g_signal_new ( "view-selection-changed" ,
+                                                  G_OBJECT_CLASS_TYPE (klass),
+                                                  G_SIGNAL_RUN_LAST,
+                                                  0,
+                                                  NULL,
+                                                  NULL,
+                                                  g_cclosure_marshal_VOID__VOID,
+                                                  G_TYPE_NONE,
+                                                  0);
+
 }
 
 BjbMainView *
@@ -566,7 +606,54 @@ void
 bjb_main_view_update_model (BjbMainView *self)
 {
   BjbMainViewPriv *priv = self->priv;
-  
-  bjb_controller_set_main_view (priv->controller,priv->view);
-  gd_main_view_set_model(priv->view,bjb_controller_get_model(priv->controller));
+
+  bjb_controller_update_view (priv->controller);
+  gd_main_view_set_model (priv->view, bjb_controller_get_model (priv->controller));
+}
+
+BjbSearchToolbar *
+bjb_main_view_get_search_toolbar (BjbMainView *view)
+{
+  g_return_val_if_fail (BJB_IS_MAIN_VIEW (view), NULL);
+
+  return view->priv->search_bar;
+}
+
+gpointer
+bjb_main_view_get_main_toolbar (BjbMainView *view)
+{
+  g_return_val_if_fail (BJB_IS_MAIN_VIEW (view), NULL);
+
+  return (gpointer) view->priv->main_toolbar;
+}
+
+/* interface for notes view (GdMainView) */
+gboolean
+bjb_main_view_get_selection_mode (BjbMainView *self)
+{
+  return gd_main_view_get_selection_mode (self->priv->view);
+}
+
+void
+bjb_main_view_set_selection_mode (BjbMainView *self, gboolean mode)
+{
+  gd_main_view_set_selection_mode (self->priv->view, mode);
+}
+
+GdMainViewType
+bjb_main_view_get_view_type (BjbMainView *view)
+{
+  return gd_main_view_get_view_type (view->priv->view);
+}
+
+void
+bjb_main_view_set_view_type (BjbMainView *view, GdMainViewType type)
+{
+  gd_main_view_set_view_type (view->priv->view, type);
+}
+
+GList *
+bjb_main_view_get_selection (BjbMainView *view)
+{
+  return gd_main_view_get_selection (view->priv->view);
 }
