@@ -23,6 +23,7 @@
 #include <libbiji/libbiji.h>
 
 #include "bjb-controller.h"
+#include "bjb-search-toolbar.h"
 
 G_BEGIN_DECLS
 
@@ -61,13 +62,13 @@ void action_new_window_callback(GtkAction *action, gpointer bjb_main_view);
 
 /* Currently it simply looks for first selected note found. Maybe most common color?
  * Or use default color when several ones including at least one default color?*/
-gboolean bjb_main_view_get_selected_notes_color (BjbMainView *view, GdkRGBA *color);
+gboolean bjb_main_view_get_selected_items_color (BjbMainView *view, GdkRGBA *color);
 
-void action_color_selected_notes (GtkWidget *w,BjbMainView *view);
+void action_color_selected_items (GtkWidget *w,BjbMainView *view);
 
-void action_tag_selected_notes (GtkWidget *w, BjbMainView *view);
+void action_tag_selected_items (GtkWidget *w, BjbMainView *view);
 
-void action_delete_selected_notes(GtkWidget *w,BjbMainView *view);
+void action_delete_selected_items (GtkWidget *w,BjbMainView *view);
 
 gboolean bjb_main_view_get_iter_at_note (BjbMainView  *view,
                                          BijiNoteObj  *note,
@@ -81,6 +82,23 @@ void switch_to_note_view(BjbMainView *view,BijiNoteObj *note) ;
 
 void bjb_main_view_update_model (BjbMainView *view);
 
+BjbSearchToolbar *bjb_main_view_get_search_toolbar (BjbMainView *view);
+
+gpointer bjb_main_view_get_main_toolbar (BjbMainView *view);
+
+/* bridge for notes view (GdMainView)
+ * TODO : get rid of this it's a bit idiot */
+
+gboolean bjb_main_view_get_selection_mode (BjbMainView *view);
+
+void bjb_main_view_set_selection_mode (BjbMainView *view, gboolean mode);
+
+GdMainViewType bjb_main_view_get_view_type (BjbMainView *view);
+
+void bjb_main_view_set_view_type (BjbMainView *view, GdMainViewType type);
+
+GList *bjb_main_view_get_selection (BjbMainView *view);
+
 G_END_DECLS
 
 #endif /* _MAIN_VIEW_H_ */
