@@ -33,7 +33,7 @@ on_email_note_callback(GtkWidget *widget, BijiNoteObj *note)
   error = NULL;
   gchar *title_mail, *text_mail;
 
-  title_mail = mail_str (biji_note_obj_get_title (note));
+  title_mail = mail_str (biji_item_get_title (BIJI_ITEM (note)));
   text_mail = mail_str (biji_note_get_raw_text (note));
 
   gchar *execute[7] = { "xdg-email",
