@@ -1,5 +1,4 @@
 
-#include <glib/gi18n.h>
 #include <glib/gprintf.h>
 #include <stdlib.h>
 
@@ -7,17 +6,26 @@
 #include <libgd/gd.h>
 
 #include "bjb-bijiben.h"
+#include "bjb-empty-results-box.h"
 #include "bjb-window-base.h"
+#include "bjb-main-toolbar.h"
 #include "bjb-main-view.h"
 #include "bjb-note-view.h"
 
 
-#define BJB_WIDTH 880
+#define BJB_WIDTH 780
 #define BJB_HEIGHT 600
-#define BIJIBEN_MAIN_WIN_TITLE N_("Notes")
+#define BIJIBEN_MAIN_WIN_TITLE "Bijiben"
 
 #define BJB_DEFAULT_FONT "Serif 10"
 
+enum {
+  BJB_WIN_BASE_VIEW_CHANGED,
+  BJB_WIN_BASE_SIGNALS
+};
+
+static guint bjb_win_base_signals [BJB_WIN_BASE_SIGNALS] = { 0 };
+
 /* As the main window remains, it owns the data */
 struct _BjbWindowBasePriv
 {
@@ -28,9 +36,15 @@ struct _BjbWindowBasePriv
   /* UI
    * The Notebook always has a main view.
    * When editing a note, it _also_ has a note view */
+  GtkWidget            *vbox;
   GdStack              *stack;
+  GtkWidget            *spinner; // this spinner takes the whole place
+                                 // and only shows on startup
+  GtkWidget            *no_note;
+
   BjbWindowViewType     current_view;
   BjbMainView          *view;
+  BjbMainToolbar       *main_toolbar;
   gchar                *entry;
 
   /* when a note is opened */
@@ -95,7 +109,7 @@ bjb_window_base_constructed (GObject *obj)
 
   gtk_window_set_default_size (GTK_WINDOW (self), BJB_WIDTH, BJB_HEIGHT);
   gtk_window_set_position (GTK_WINDOW (self),GTK_WIN_POS_CENTER);
-  gtk_window_set_title (GTK_WINDOW (self), _(BIJIBEN_MAIN_WIN_TITLE));
+  gtk_window_set_title (GTK_WINDOW (self), BIJIBEN_MAIN_WIN_TITLE);
 
   /* Icon for window. TODO - Should be BjbApp */
   icons_path = bijiben_get_bijiben_dir ();
@@ -125,10 +139,6 @@ bjb_window_base_constructed (GObject *obj)
   priv->entry = NULL ;
   priv->font = pango_font_description_from_string (BJB_DEFAULT_FONT);
 
-  /* UI : basic notebook */
-  priv->stack = GD_STACK (gd_stack_new ());
-  gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (priv->stack));
-
   /* Signals */
   g_signal_connect(GTK_WIDGET(self),"destroy",
                    G_CALLBACK(bjb_window_base_destroy),self);
@@ -137,12 +147,17 @@ bjb_window_base_constructed (GObject *obj)
 static void
 bjb_window_base_init (BjbWindowBase *self)
 {
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
-                                            BJB_TYPE_WINDOW_BASE,
-                                            BjbWindowBasePriv);
+  BjbWindowBasePriv *priv;
+  priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
+                                      BJB_TYPE_WINDOW_BASE,
+                                      BjbWindowBasePriv);
+  self->priv = priv;
 
   /* Default window has no note opened */
-  self->priv->note_view = NULL;
+  priv->note_view = NULL;
+
+  priv->vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+  gtk_container_add (GTK_CONTAINER (self), priv->vbox);
 }
 
 static void
@@ -155,6 +170,16 @@ bjb_window_base_class_init (BjbWindowBaseClass *klass)
   gobject_class->finalize = bjb_window_base_finalize ;
 
   g_type_class_add_private (klass, sizeof (BjbWindowBasePriv));
+
+  bjb_win_base_signals[BJB_WIN_BASE_VIEW_CHANGED] = g_signal_new ("view-changed" ,
+                                                    G_OBJECT_CLASS_TYPE (klass),
+                                                    G_SIGNAL_RUN_LAST,
+                                                    0,
+                                                    NULL,
+                                                    NULL,
+                                                    g_cclosure_marshal_VOID__VOID,
+                                                    G_TYPE_NONE,
+                                                    0);
 }
 
 GtkWindow *
@@ -168,15 +193,33 @@ bjb_window_base_new(void)
                         "hide-titlebar-when-maximized", TRUE,
                         NULL);
 
-  /* Rather dirty to finish UI there. maybe bjb_w_b_set_controller */
+  /* Rather dirty to finish UI there */
 
   priv = retval->priv;
 
   priv->controller = bjb_controller_new 
     (bijiben_get_book (BIJIBEN_APPLICATION(g_application_get_default())),
+     GTK_WINDOW (retval),
      priv->entry );
 
+  /* Shared toolbar */
   priv->view = bjb_main_view_new (GTK_WIDGET (retval), priv->controller);
+  priv->main_toolbar = bjb_main_toolbar_new (priv->view, priv->controller);
+  gtk_box_pack_start (GTK_BOX (priv->vbox), GTK_WIDGET (priv->main_toolbar), FALSE, FALSE, 0);
+
+  /* UI : stack for different views */
+  priv->stack = GD_STACK (gd_stack_new ());
+  gtk_box_pack_start (GTK_BOX (priv->vbox), GTK_WIDGET (priv->stack), TRUE, TRUE, 0);
+
+  priv->spinner = gtk_spinner_new ();
+  gd_stack_add_named (priv->stack, priv->spinner, "spinner");
+  gd_stack_set_visible_child_name (priv->stack, "spinner");
+  gtk_widget_show (priv->spinner);
+  gtk_spinner_start (GTK_SPINNER (priv->spinner));
+
+  priv->no_note = bjb_empty_results_box_new ();
+  gd_stack_add_named (priv->stack, priv->no_note, "empty");
+
   gd_stack_add_named (priv->stack, GTK_WIDGET (priv->view), "main-view");
   gtk_widget_show_all (GTK_WIDGET (retval));
 
@@ -196,14 +239,6 @@ window_base_get_font(GtkWidget *window)
   return b->priv->font ;
 }
 
-void
-bjb_window_base_set_note (BjbWindowBase *self, BijiNoteObj *note)
-{
-  g_return_if_fail (BJB_IS_WINDOW_BASE (self));
-
-  self->priv->note = note;
-}
-
 BijiNoteObj *
 bjb_window_base_get_note (BjbWindowBase *self)
 {
@@ -225,11 +260,12 @@ void
 bjb_window_base_switch_to (BjbWindowBase *bwb, BjbWindowViewType type)
 {
   BjbWindowBasePriv *priv = bwb->priv;
+  priv->current_view = type;
 
   /* Precise the window does not display any specific note
    * Refresh the model
    * Ensure the main view receives the proper signals */
-  if (type == BJB_MAIN_VIEW)
+  if (type == BJB_WINDOW_BASE_MAIN_VIEW)
   {
     priv->note = NULL;
     bjb_main_view_connect_signals (priv->view);
@@ -238,11 +274,35 @@ bjb_window_base_switch_to (BjbWindowBase *bwb, BjbWindowViewType type)
     destroy_note_if_needed (bwb);
   }
 
+  else if (type == BJB_WINDOW_BASE_SPINNER_VIEW)
+  {
+    priv->note = NULL;
+    gd_stack_set_visible_child_name (priv->stack, "spinner");
+  }
+
+  else if (type == BJB_WINDOW_BASE_NO_NOTE)
+  {
+    bjb_empty_results_box_set_type (BJB_EMPTY_RESULTS_BOX (priv->no_note),
+                                    BJB_EMPTY_RESULTS_NO_NOTE);
+    gtk_widget_show (priv->no_note);
+    gd_stack_set_visible_child_name (priv->stack, "empty");
+  }
+
+  else if (type == BJB_WINDOW_BASE_NO_RESULT)
+  {
+    bjb_empty_results_box_set_type (BJB_EMPTY_RESULTS_BOX (priv->no_note),
+                                    BJB_EMPTY_RESULTS_NO_RESULTS);
+    gtk_widget_show (priv->no_note);
+    gd_stack_set_visible_child_name (priv->stack, "empty");
+  }
+
   else
   {
     gtk_widget_show_all (GTK_WIDGET (priv->note_overlay));
     gd_stack_set_visible_child_name (priv->stack, "note-view");
   }
+
+  g_signal_emit (G_OBJECT (bwb), bjb_win_base_signals[BJB_WIN_BASE_VIEW_CHANGED],0);
 }
 
 void
@@ -255,16 +315,23 @@ bjb_window_base_switch_to_note (BjbWindowBase *bwb, BijiNoteObj *note)
 
   priv->note = note;
   priv->note_overlay = gtk_overlay_new ();
+
   gd_stack_add_named (priv->stack, priv->note_overlay, "note-view");
   priv->note_view = bjb_note_view_new (w, priv->note_overlay, note);
+
   g_object_add_weak_pointer (G_OBJECT (priv->note_view),
                              (gpointer *) &priv->note_view);
 
-  bjb_window_base_set_note (bwb, priv->note);
-  bjb_window_base_switch_to (bwb, BJB_NOTE_VIEW);
+  bjb_window_base_switch_to (bwb, BJB_WINDOW_BASE_NOTE_VIEW);
   gtk_widget_show_all (w);
 }
 
+BjbWindowViewType
+bjb_window_base_get_view_type (BjbWindowBase *win)
+{
+  return win->priv->current_view;
+}
+
 BijiNoteBook *
 bjb_window_base_get_book(GtkWidget * win)
 {
