@@ -4,7 +4,6 @@
 #include <gtk/gtk.h>
 #include <libbiji/libbiji.h>
 
-#include "bjb-settings.h"
 #include "bjb-controller.h"
 
 #define BJB_TYPE_WINDOW_BASE                  (bjb_window_base_get_type ())
@@ -32,9 +31,12 @@ struct _BjbWindowBase
 };
 
 typedef enum {
-  BJB_MAIN_VIEW,
-  BJB_NOTE_VIEW,
-  BJB_NO_VIEW
+  BJB_WINDOW_BASE_MAIN_VIEW,
+  BJB_WINDOW_BASE_SPINNER_VIEW,
+  BJB_WINDOW_BASE_NOTE_VIEW,
+  BJB_WINDOW_BASE_NO_NOTE,
+  BJB_WINDOW_BASE_NO_RESULT,
+  BJB_WINDOW_BASE_NO_VIEW
 } BjbWindowViewType;
 
 GType bjb_window_base_get_type (void);
@@ -51,6 +53,8 @@ void bjb_window_base_switch_to (BjbWindowBase *bwb, BjbWindowViewType type);
 
 void bjb_window_base_switch_to_note (BjbWindowBase *bwb, BijiNoteObj *note);
 
+BjbWindowViewType bjb_window_base_get_view_type (BjbWindowBase *win);
+
 BijiNoteBook * bjb_window_base_get_book(GtkWidget * win);
 
 void bjb_window_base_set_entry(GtkWidget *win, gchar *search_entry) ;
@@ -63,8 +67,6 @@ gpointer bjb_window_base_get_main_view (BjbWindowBase *self);
 
 BijiNoteObj * bjb_window_base_get_note (BjbWindowBase *self);
 
-void bjb_window_base_set_note (BjbWindowBase *self, BijiNoteObj *note);
-
 gboolean switch_window_fullscreen();
 
 #endif /* _BJB_WINDOW_BASE_H */
