@@ -27,11 +27,6 @@
 
 #include <libgd/gd.h>
 
-/* Icon */
-#define ICON_WIDTH 200
-#define ICON_HEIGHT 240
-#define ICON_FONT "Purusa 10"
-
 struct _BijiNoteObjPrivate
 {
   /* Notebook might be null. */
@@ -50,9 +45,12 @@ struct _BijiNoteObjPrivate
   BijiTimeout           *timeout;
   gboolean              needs_save;
 
-  /* Icon might be null untill usefull */
+  /* Icon might be null untill usefull
+   * Emblem is smaller & just shows the color */
   GdkPixbuf             *icon;
+  GdkPixbuf             *emblem;
   gboolean              icon_needs_update;
+  gboolean              emblem_needs_update;
 
   /* Tags 
    * In Tomboy, templates are 'system:notebook:%s' tags.*/
@@ -77,7 +75,18 @@ static GParamSpec *properties[BIJI_OBJ_PROPERTIES] = { NULL, };
 
 #define BIJI_NOTE_OBJ_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BIJI_TYPE_NOTE_OBJ, BijiNoteObjPrivate))
 
-G_DEFINE_TYPE (BijiNoteObj, biji_note_obj, G_TYPE_OBJECT);
+G_DEFINE_TYPE (BijiNoteObj, biji_note_obj, BIJI_TYPE_ITEM);
+
+/* BijiItem iface */
+static gchar     * biji_note_obj_get_title                (BijiItem *note);
+static gchar     * biji_note_obj_get_path                 (BijiItem *note);
+static GdkPixbuf * biji_note_obj_get_icon                 (BijiItem *note);
+static GdkPixbuf * biji_note_obj_get_emblem               (BijiItem *note);
+static gboolean    biji_note_obj_trash                    (BijiItem *note);
+static glong       biji_note_obj_get_last_change_date_sec (BijiItem *note);
+static gboolean    biji_note_obj_has_collection           (BijiItem *note, gchar *label);
+static gboolean    biji_note_obj_add_collection           (BijiItem *note, gchar *label, gboolean on_user_action);
+static gboolean    biji_note_obj_remove_collection        (BijiItem *note, gchar *label, gchar *urn);
 
 static void
 on_save_timeout (BijiNoteObj *self)
@@ -126,6 +135,7 @@ biji_note_obj_init (BijiNoteObj *self)
 
   /* Icon is only computed when necessary */
   priv->icon = NULL;
+  priv->emblem = NULL;
 
   /* Keep value unitialied, so bijiben knows to assign default color */
   priv->color = NULL;
@@ -156,6 +166,7 @@ biji_note_obj_finalize (GObject *object)
   g_hash_table_destroy (priv->labels);
 
   g_clear_object (&priv->icon);
+  g_clear_object (&priv->emblem);
   gdk_rgba_free (priv->color);
 
   G_OBJECT_CLASS (biji_note_obj_parent_class)->finalize (object);
@@ -221,7 +232,8 @@ biji_note_obj_get_property (GObject    *object,
 static void
 biji_note_obj_class_init (BijiNoteObjClass *klass)
 {
-  GObjectClass* object_class = G_OBJECT_CLASS (klass);
+  BijiItemClass*  item_class = BIJI_ITEM_CLASS (klass);
+  GObjectClass* object_class = G_OBJECT_CLASS  (klass);
 
   object_class->constructed = biji_note_obj_constructed;
   object_class->finalize = biji_note_obj_finalize;
@@ -278,6 +290,17 @@ biji_note_obj_class_init (BijiNoteObjClass *klass)
                                                   0);
 
   g_type_class_add_private (klass, sizeof (BijiNoteObjPrivate));
+
+  /* Interface */
+  item_class->get_title = biji_note_obj_get_title;
+  item_class->get_uuid = biji_note_obj_get_path;
+  item_class->get_icon = biji_note_obj_get_icon;
+  item_class->get_emblem = biji_note_obj_get_emblem;
+  item_class->get_change_sec = biji_note_obj_get_last_change_date_sec;
+  item_class->trash = biji_note_obj_trash;
+  item_class->has_collection = biji_note_obj_has_collection;
+  item_class->add_collection = biji_note_obj_add_collection;
+  item_class->remove_collection = biji_note_obj_remove_collection;
 }
 
 BijiNoteObj *
@@ -325,14 +348,18 @@ biji_note_obj_are_same (BijiNoteObj *a, BijiNoteObj* b)
 /* First cancel timeout
  * this func is most probably stupid it might exists (move file) */
 gboolean
-biji_note_obj_trash (BijiNoteObj *note_to_kill)
+biji_note_obj_trash (BijiItem *item)
 {
-  BijiNoteObjPrivate *priv = note_to_kill->priv;
+  BijiNoteObj *note_to_kill;
+  BijiNoteObjPrivate *priv;
   GFile *to_trash, *parent, *trash, *backup_file, *icon;
   gchar *note_name, *parent_path, *trash_path, *backup_path, *icon_path;
   GError *error = NULL;
   gboolean result = FALSE;
 
+  note_to_kill = BIJI_NOTE_OBJ (item);
+  priv = note_to_kill->priv;
+
   priv->needs_save = FALSE;
   biji_timeout_cancel (priv->timeout);
 
@@ -394,11 +421,14 @@ biji_note_obj_trash (BijiNoteObj *note_to_kill)
   return result;
 }
 
-gchar* biji_note_obj_get_path (BijiNoteObj* n)
+static gchar *
+biji_note_obj_get_path (BijiItem *item)
 {
-  g_return_val_if_fail (BIJI_IS_NOTE_OBJ (n), NULL);
+  g_return_val_if_fail (BIJI_IS_NOTE_OBJ (item), NULL);
 
-  return biji_note_id_get_path(n->priv->id) ;
+  BijiNoteObj *note = BIJI_NOTE_OBJ (item);
+
+  return biji_note_id_get_path (note->priv->id);
 }
 
 BijiNoteID* note_get_id(BijiNoteObj* n)
@@ -406,12 +436,12 @@ BijiNoteID* note_get_id(BijiNoteObj* n)
   return n->priv->id;
 }
 
-gchar *
-biji_note_obj_get_title(BijiNoteObj *obj)
+static gchar *
+biji_note_obj_get_title (BijiItem *note)
 {
-  g_return_val_if_fail (BIJI_IS_NOTE_OBJ(obj), NULL);
+  g_return_val_if_fail (BIJI_IS_NOTE_OBJ (note), NULL);
 
-  return biji_note_id_get_title (obj->priv->id);
+  return biji_note_id_get_title (BIJI_NOTE_OBJ (note)->priv->id);
 }
 
 /* If already a title, then note is renamed */
@@ -469,10 +499,12 @@ biji_note_obj_set_last_change_date (BijiNoteObj* n,gchar* date)
   return biji_note_id_set_last_change_date (n->priv->id,date);
 }
 
-glong 
-biji_note_obj_get_last_change_date_sec ( BijiNoteObj *n )
+static glong
+biji_note_obj_get_last_change_date_sec (BijiItem *item)
 {
-  return biji_note_id_get_last_change_date_sec(note_get_id(n)); 
+  BijiNoteObj *n = BIJI_NOTE_OBJ (item);
+
+  return biji_note_id_get_last_change_date_sec(note_get_id(n));
 }
 
 gchar *
@@ -511,6 +543,7 @@ biji_note_obj_set_rgba_internal (BijiNoteObj *n, GdkRGBA *rgba)
 {
   n->priv->color = gdk_rgba_copy(rgba);
   n->priv->icon_needs_update = TRUE;
+  n->priv->emblem_needs_update = TRUE;
 
   g_signal_emit (G_OBJECT (n), biji_obj_signals[NOTE_COLOR_CHANGED],0);
 }
@@ -548,7 +581,7 @@ biji_note_obj_get_rgba(BijiNoteObj *n,
 }
 
 static void
-biji_note_obj_clear_icon (BijiNoteObj *note)
+biji_note_obj_clear_icons (BijiNoteObj *note)
 {
   if (note->priv->icon)
   {
@@ -556,6 +589,12 @@ biji_note_obj_clear_icon (BijiNoteObj *note)
     note->priv->icon = NULL ;
   }
 
+  if (note->priv->emblem)
+  {
+    g_clear_object (&note->priv->emblem);
+    note->priv->emblem = NULL ;
+  }
+
   g_signal_emit (G_OBJECT (note), biji_obj_signals[NOTE_CHANGED],0);
 }
 
@@ -565,7 +604,7 @@ void biji_note_obj_set_raw_text (BijiNoteObj *note, gchar *plain_text)
     g_free (note->priv->raw_text);
 
   note->priv->raw_text = g_strdup (plain_text);
-  biji_note_obj_clear_icon (note);
+  biji_note_obj_clear_icons (note);
 }
 
 GList *
@@ -577,8 +616,10 @@ biji_note_obj_get_collections (BijiNoteObj *n)
 }
 
 gboolean
-biji_note_obj_has_collection (BijiNoteObj *note, gchar *label)
+biji_note_obj_has_collection (BijiItem *item, gchar *label)
 {
+  BijiNoteObj *note = BIJI_NOTE_OBJ (item);
+
   if (g_hash_table_lookup (note->priv->labels, label))
     return TRUE;
 
@@ -586,12 +627,13 @@ biji_note_obj_has_collection (BijiNoteObj *note, gchar *label)
 }
 
 gboolean
-biji_note_obj_add_collection (BijiNoteObj *note, gchar *label, gboolean on_user_action_cb)
+biji_note_obj_add_collection (BijiItem *item, gchar *label, gboolean on_user_action_cb)
 {
-  g_return_val_if_fail (BIJI_IS_NOTE_OBJ (note), FALSE);
+  g_return_val_if_fail (BIJI_IS_NOTE_OBJ (item), FALSE);
   g_return_val_if_fail (label != NULL, FALSE);
-  g_return_val_if_fail (!biji_note_obj_has_collection (note, label), FALSE);
+  g_return_val_if_fail (!biji_note_obj_has_collection (item, label), FALSE);
 
+  BijiNoteObj *note = BIJI_NOTE_OBJ (item);
   gchar *tag = g_strdup (label);
 
   g_hash_table_add (note->priv->labels, tag);
@@ -607,9 +649,10 @@ biji_note_obj_add_collection (BijiNoteObj *note, gchar *label, gboolean on_user_
 }
 
 gboolean
-biji_note_obj_remove_collection (BijiNoteObj *note, gchar *label, gchar *urn)
+biji_note_obj_remove_collection (BijiItem *item, gchar *label, gchar *urn)
 {
-  g_return_val_if_fail (BIJI_IS_NOTE_OBJ (note), FALSE);
+  g_return_val_if_fail (BIJI_IS_NOTE_OBJ (item), FALSE);
+  BijiNoteObj *note = BIJI_NOTE_OBJ (item);
 
   if (g_hash_table_remove (note->priv->labels, label))
   {
@@ -696,8 +739,8 @@ biji_note_obj_set_icon (BijiNoteObj *note, GdkPixbuf *pix)
     g_warning ("Cannot use _set_icon_ with iconified note. This has no sense.");
 }
 
-GdkPixbuf *
-biji_note_obj_get_icon (BijiNoteObj *note)
+static GdkPixbuf *
+biji_note_obj_get_icon (BijiItem *item)
 {
   GdkRGBA               note_color;
   gchar                 *text;
@@ -708,17 +751,19 @@ biji_note_obj_get_icon (BijiNoteObj *note)
   cairo_surface_t       *surface = NULL;
   GtkBorder              frame_slice = { 4, 3, 3, 6 };
 
+  BijiNoteObj *note = BIJI_NOTE_OBJ (item);
+
   if (note->priv->icon && !note->priv->icon_needs_update)
     return note->priv->icon;
 
-  /* Create & Draw surface */ 
-  surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32 , 
-                                        ICON_WIDTH,
-                                        ICON_HEIGHT) ;
+  /* Create & Draw surface */
+  surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
+                                        BIJI_ICON_WIDTH,
+                                        BIJI_ICON_HEIGHT) ;
   cr = cairo_create (surface);
 
   /* Background */
-  cairo_rectangle (cr, 0, 0, ICON_WIDTH, ICON_HEIGHT);
+  cairo_rectangle (cr, 0, 0, BIJI_ICON_WIDTH, BIJI_ICON_HEIGHT);
   if (biji_note_obj_get_rgba (note, &note_color))
     gdk_cairo_set_source_rgba (cr, &note_color);
 
@@ -736,7 +781,7 @@ biji_note_obj_get_icon (BijiNoteObj *note)
     pango_layout_set_height (layout, 180000 ) ;
 
     pango_layout_set_text (layout, text, -1);
-    desc = pango_font_description_from_string (ICON_FONT);
+    desc = pango_font_description_from_string (BIJI_ICON_FONT);
     pango_layout_set_font_description (layout, desc);
     pango_font_description_free (desc);
 
@@ -751,8 +796,8 @@ biji_note_obj_get_icon (BijiNoteObj *note)
 
   ret = gdk_pixbuf_get_from_surface (surface,
                                      0, 0,
-                                     ICON_WIDTH,
-                                     ICON_HEIGHT);
+                                     BIJI_ICON_WIDTH,
+                                     BIJI_ICON_HEIGHT);
   cairo_surface_destroy (surface);
 
   note->priv->icon = gd_embed_image_in_frame (ret, "resource:///org/gnome/bijiben/thumbnail-frame.png",
@@ -763,6 +808,49 @@ biji_note_obj_get_icon (BijiNoteObj *note)
   return note->priv->icon;
 }
 
+static GdkPixbuf *
+biji_note_obj_get_emblem (BijiItem *item)
+{
+  GdkRGBA                note_color;
+  cairo_t               *cr;
+  cairo_surface_t       *surface = NULL;
+  BijiNoteObj           *note = BIJI_NOTE_OBJ (item);
+
+  if (note->priv->emblem && !note->priv->emblem_needs_update)
+    return note->priv->emblem;
+
+  /* Create & Draw surface */
+  surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
+                                        BIJI_EMBLEM_WIDTH,
+                                        BIJI_EMBLEM_HEIGHT) ;
+  cr = cairo_create (surface);
+
+  /* Background */
+  cairo_rectangle (cr, 0, 0, BIJI_EMBLEM_WIDTH, BIJI_EMBLEM_HEIGHT);
+  if (biji_note_obj_get_rgba (note, &note_color))
+    gdk_cairo_set_source_rgba (cr, &note_color);
+
+  cairo_fill (cr);
+
+  /* Border */
+  cairo_set_source_rgba (cr, 0.3, 0.3, 0.3, 1);
+  cairo_set_line_width (cr, 1);
+  cairo_rectangle (cr, 0, 0, BIJI_EMBLEM_WIDTH, BIJI_EMBLEM_HEIGHT);
+  cairo_stroke (cr);
+
+  cairo_destroy (cr);
+
+  note->priv->emblem = gdk_pixbuf_get_from_surface (surface,
+                                                    0, 0,
+                                                    BIJI_EMBLEM_WIDTH,
+                                                    BIJI_EMBLEM_HEIGHT);
+
+  cairo_surface_destroy (surface);
+  note->priv->emblem_needs_update = FALSE;
+
+  return note->priv->emblem;
+}
+
 /* Single Note */
 
 gchar *
@@ -871,7 +959,7 @@ _biji_note_obj_close (BijiNoteObj *note)
    * since no change could trigger save */
   if (!priv->raw_text)
   {
-    biji_note_book_remove_note (priv->book, note);
+    biji_note_book_remove_item (priv->book, BIJI_ITEM (note));
   }
 
   /* If the note only has one row. put some title */
